# -*- encoding:utf-8 -*-
from django.db import models
from django.contrib.auth.models import User
from datetime import datetime

from django.contrib.contenttypes import generic
from sample.comment.models import Comment

class Tag(models.Model):
    TAG_TYPE = ((1, u'プログラミング'), (2, u'サーフィン'), (3, u'ショッピング'), )
    
    name = models.CharField(u'タグ', max_length=100)
    tag_type = models.IntegerField(u'タグ種別', choices=TAG_TYPE)

class Entry(models.Model) :
    slug = models.SlugField(u'スラグ', unique_for_date='create_date', prepopulate_from=('title',),\
              help_text=u'URLの一部に利用されます。タイトルにアスキー文字以外の文字を入力した場合には、自分で入力しなければなりません。')
    title = models.CharField(u'タイトル', max_length=250, blank=False)
    author = models.ForeignKey(User, verbose_name=u'著者')
    body = models.TextField(u'本文', blank=False)
    create_date = models.DateTimeField(u'作成日', editable=False)
    update_date = models.DateTimeField(u'更新日', editable=False)
    visible = models.BooleanField(u'表示', default=True, help_text=u'チェックしない場合には、ログインしたユーザーにのみ表示します')

    tags = models.ManyToManyField(Tag, verbose_name=u'このエントリのタグ', blank=True)

    comments = generic.GenericRelation(Comment)
    
    def get_absolute_url(self):
        return '/blog/%s/%s/' % ( (self.create_date.strftime("%Y/%m/%d"), self.slug, )) 

    class Meta:
        verbose_name = u'エントリ'
        verbose_name_plural = u'エントリ'
        get_latest_by = 'create_date'
        ordering = ('-create_date',)

    class Admin:
        list_display = ('title', 'author', 'create_date', 'visible',)
        list_filter = ('create_date','visible',)
        date_hierarchy = 'create_date'
        search_fields = ('title', 'body',)


    def __unicode__(self) :
        return self.title

    def save(self):
        if not self.id:
            self.create_date = datetime.now()
        self.update_date = datetime.now()
        # do something
        super(Entry, self).save()
        # do something
