# -*- encoding:utf-8 -*-
from django.db import models
from django.contrib.auth.models import User
from sample.comment.models import Comment
from django.contrib.contenttypes import generic

from datetime import datetime
from django.db.models import signals
from django.dispatch import dispatcher

class Page(models.Model):
    url = models.URLField(blank=False, verify_exists=False)
    count = models.PositiveIntegerField(editable=False, blank=False, default=0)

class Bookmark(models.Model):
    page = models.ForeignKey(Page, verbose_name=u'ページ')
    user = models.ForeignKey(User, verbose_name=u'ブックマークユーザー')
    added = models.DateTimeField(u'登録日', blank=True)
    updated = models.DateTimeField(u'更新日', blank=True)
    tags = models.ManyToManyField('Tag', blank=True, verbose_name=u'タグ')

    comments = generic.GenericRelation(Comment)

class Tag(models.Model):
    name = models.CharField(u'タグ', max_length=100)

def bm_pre_save(signal, sender, instance, **kwds):
    if not instance.id:
        instance.added = datetime.now()
    instance.updated = datetime.now()

dispatcher.connect(bm_pre_save, sender=Bookmark, signal=signals.pre_save)

