# -*- encoding:utf-8 -*-
from django.db import models
from datetime import datetime

class Company(models.Model):
    code = models.CharField(u'会社コード', max_length=4, db_index=True, unique=True)
    name = models.CharField(u'会社名', max_length=100)

class Section(models.Model): 
    company = models.ForeignKey(Company, verbose_name=u'会社')
    code = models.CharField(u'部署コード', max_length=8, db_index=True)
    name = models.CharField(u'部署名', max_length=100)
    delete_flag = models.BooleanField(u'削除フラグ', default=False)
    parent = models.ForeignKey(u'self', blank=True, null=True, related_name='child_set')

class Employee(models.Model): 
    section = models.ForeignKey(Section, verbose_name=u'部署')
    name = models.CharField(u'氏名', max_length=64, db_index=True)
    email = models.EmailField(u'メールアドレス', db_index=True)
    memo = models.TextField(u'備考', blank=True)
    valid_from = models.DateTimeField(u'有効期限(開始)', blank=True, null=True, default=datetime.now)
    valid_to = models.DateTimeField(u'有効期限(終了)', blank=True, null=True)

