# coding: utf-8
from django import template

register = template.Library()

def lower(value):
  return value.lower()

def cut(value, arg):
  return value.replace(arg, '')

register.filter('lower', lower)
register.filter('cut', cut)


import datetime
from django import template

class CurrentTimeNode(template.Node):

    def __init__(self, format_string):
        self.format_string = str(format_string)
        
    def render(self, context):
        return datetime.datetime.now().strftime(self.format_string)

def do_current_time(parser, token):
    try:
        tag_name, format_string = token.split_contents()
    except ValueError:
        raise template.TemplateSyntaxError, \
            "%r tag requires a single argument" % token.contents[0]
 
    if not (format_string[0] == format_string[-1] and \
        format_string[0] in ('"', "'")):
        raise template.TemplateSyntaxError, \
          "%r tag's argument should be in quotes" % tag_name
    return CurrentTimeNode(format_string[1:-1])

register.tag('current_time', do_current_time)

import datetime
from django import template
from django.template import resolve_variable, VariableDoesNotExist
    
class FormatTimeNode(template.Node):
        
    def __init__(self, date_to_be_formatted, format_string):
        self.date_to_be_formatted = date_to_be_formatted
        self.format_string = str(format_string)

    def render(self, context):
        try:
            actual_date = resolve_variable(self.date_to_be_formatted, context)
            return actual_date.strftime(self.format_string)
        except VariableDoesNotExist:
            return ''
    
def do_format_time(parser, token):
    try:
        tag_name, date_to_be_formatted, format_string = token.split_contents()
        # date_to_be_formattedが文字列で返ってくる
    except ValueError:
        raise template.TemplateSyntaxError, "%r tag requires exactly two arguments" % token.contents[0]
    if not (format_string[0] == format_string[-1] and format_string[0] in ('"', 
"'")):
        raise template.TemplateSyntaxError, "%r tag's argument should be in quotes" % tag_name
    return FormatTimeNode(date_to_be_formatted, format_string[1:-1])

register.tag('format_time', do_format_time)

class CurrentTimeNode2(template.Node):
    def __init__(self, format_string):
        self.format_string = str(format_string)
    def render(self, context):
        context['current_time'] = \
            datetime.datetime.now().strftime(self.format_string)
        return ''

def do_current_time2(parser, token):
    try:
        tag_name, format_string = token.split_contents()
    except ValueError:
        raise template.TemplateSyntaxError, \
            "%r tag requires a single argument" % token.contents[0]
 
    if not (format_string[0] == format_string[-1] and \
        format_string[0] in ('"', "'")):
        raise template.TemplateSyntaxError, \
          "%r tag's argument should be in quotes" % tag_name
    return CurrentTimeNode2(format_string[1:-1])

register.tag('current_time2', do_current_time2)

import re

class CurrentTimeNode3(template.Node):

    def __init__(self, format_string, var_name):
        self.format_string = str(format_string)
        self.var_name = var_name
        
    def render(self, context):
        context[self.var_name] = \
            datetime.datetime.now().strftime(self.format_string)
        return ''

def do_get_current_time(parser, token):
    try:
        tag_name, arg = token.contents.split(None, 1)
    except ValueError:
        raise template.TemplateSyntaxError, \
            "%r tag requires arguments" % token.contents[0]
    m = re.search(r'(.*?) as (\w+)', arg)
    if not m:
        raise template.TemplateSyntaxError, \
              "%r tag had invalid arguments" % tag_name
    format_string, var_name = m.groups()
    if not (format_string[0] == format_string[-1] and \
        format_string[0] in ('"', "'")):
        raise template.TemplateSyntaxError, \
              "%r tag's argument should be in quotes" % tag_name
    return CurrentTimeNode3(format_string[1:-1], var_name)

register.tag('get_current_time', do_get_current_time)

def do_upper(parser, token):
    nodelist = parser.parse(('endupper',))
    parser.delete_first_token()
    return UpperNode(nodelist)

class UpperNode(template.Node):
    
    def __init__(self, nodelist):
        self.nodelist = nodelist

    def render(self, context):
        output = self.nodelist.render(context)
        return output.upper()

register.tag('upper', do_upper)

def current_time_simple(format_string):
    return datetime.datetime.now().strftime(str(format_string))

register.simple_tag(current_time_simple)
