from django.conf import settings

from djblogkit.blog.models import Entry, Comment, Trackback, Tag
from django.contrib.sites.models import Site

from django.core.cache import cache



def basic(request):
    """
    Returns context variables required by apps that use Django's authentication
    system.
    """
    blogcontext = settings.CACHE_BACKEND and cache.get(settings.BLOG_CONTEXT_CACHE_KEY, None)
    if blogcontext:
        return blogcontext
    blogcontext =  {
        'DOMAIN': Site.objects.get(pk=settings.SITE_ID).domain,
        'BLOG_TITLE': settings.BLOG_TITLE,
        'BLOG_BASE': settings.BLOG_BASE,
        'MEDIA_URL': settings.MEDIA_URL,
        'entry_list': list(Entry.public_objects.order_by('-pub_date')[:settings.LIST_COUNT]),
        'archive_list': list(Entry.public_objects.dates('pub_date', 'day')),
        'comment_list': list(Comment.objects.select_related().order_by('-create_date')[:settings.LIST_COUNT]),
        'trackback_list': list(Trackback.objects.select_related().order_by('-create_date')[:settings.LIST_COUNT]),
        'tag_list': list(Tag.objects.order_by('name')),
    }
    if settings.CACHE_BACKEND :
        cache.set(settings.BLOG_CONTEXT_CACHE_KEY, blogcontext, 60 * 60)
    return blogcontext
