from django.conf.urls.defaults import *
from django.conf import settings

from django.utils.functional import lazy

from djblogkit.blog.models import Entry, Comment, Trackback, Tag
from djblogkit.blog.feeds import DjblogkitRss, DjblogkitTagRss
from django import forms

from django.views.generic import date_based
from django.views.generic import list_detail
from django.contrib.syndication import views as syndication_views

feeds = {
    'rss': DjblogkitRss
}
tag_feeds = {
    'rss': DjblogkitTagRss
}


urlpatterns = patterns('djblogkit.blog.views',
    (r'^(?P<year>\d{4})/(?P<month>\w{1,2})/(?P<day>\w{1,2})/(?P<slug>.*)/add_comment/$',
            'add_comment', dict(), 'add_comment'),
    (r'^(?P<year>\d{4})/(?P<month>\w{1,2})/(?P<day>\w{1,2})/(?P<slug>.*)/tbping/$',
            'tbping', dict(), 'tbping'),
    (r'^(?P<year>\d{4})/(?P<month>\w{1,2})/(?P<day>\w{1,2})/(?P<slug>.*)/$',
            'entry_detail', dict(), 'entry_detail'),
    (r'^tag/(?P<tag>.*)/$', 'tag_list', dict(), 'tag_list'),

    #RSS
    (r'^feed/(?P<url>.*)/(?P<tag>.*)/$', 'tag_feed', dict() , 'tag_feed'),
)

urlpatterns += patterns('',
    (r'^$',
            list_detail.object_list,
            dict(queryset=Entry.public_objects.all().select_related(),
                 paginate_by=settings.NUM_IN_PAGE, allow_empty=True),
            'entry_list'),
    (r'^(?P<year>\d{4})/(?P<month>\w{1,2})/(?P<day>\w{1,2})/$',
            date_based.archive_day,
            dict(queryset=Entry.public_objects.all().select_related(),
                 date_field='pub_date', month_format='%m'), 'entry_archive_day'),
    (r'^(?P<year>\d{4})/(?P<month>\w{1,2})/$',
            date_based.archive_month,
            dict(queryset=Entry.public_objects.all().select_related(),
                 date_field='pub_date', month_format='%m'), 'entry_archive_month'),


    #RSS
    (r'^feed/(?P<url>.*)/$', syndication_views.feed, dict(feed_dict=feeds), 'entry_feed'),

)

#for test

urlpatterns += patterns('',
    (r'^need_login/$', 'djblogkit.blog.views.login_required_view_for_test', dict(), 'need_login')
)
if settings.DEBUG:
    urlpatterns += patterns('',
        (r'^static/(?P<path>.*)$', 'django.views.static.serve',
         {'document_root': settings.MEDIA_ROOT}),
)
