# encoding=utf8

from django.http import HttpResponse
# Django に内蔵されている simplejson 
from django.utils import simplejson

# 本来は filter 出使う機能を views.py で使う
from django.template.defaultfilters import linebreaksbr

# Memo モデルをインポート
from memo.models import Memo

def create_memo(request):
    if request.method == 'POST':
        # POST されたデータから text を取り出す
        text = request.POST['text']
        # 新しく memo を作成
        memo = Memo.objects.create(text=text)
        # text に linebreaksbr フィルタを適用します。
        memo_json = {'pk': memo.pk, 'text': linebreaksbr(memo.text)}

        # 辞書オブジェクトを JSON オブジェクトに変換します
        # ensure_ascii=False を忘れないでください。
        json = simplejson.dumps(memo_json, ensure_ascii=False)

        return HttpResponse(json, mimetype='application/json')
